@@ -93,20 +93,13 @@ sj_get_default_path_pattern (void)
   return path_patterns[0].pattern;
 }
 
-void prefs_profile_changed (GtkWidget *widget, gpointer user_data)
+static void prefs_profile_changed (GtkComboBox *combo, gpointer user_data)
 {
-  GtkTreeIter iter;
-  GtkTreeModel *model;
+  const char *media_type;
 
-  model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
-  /* Handle the change being to unselect a profile */
-  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
-    char *media_type;
-    gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
-                        0, &media_type, -1);
+  media_type = gtk_combo_box_get_active_id (combo);
+  if (media_type)
     g_settings_set_string (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, media_type);
-    g_free (media_type);
-  }
 }
 
 /**
@@ -153,70 +146,16 @@ G_MODULE_EXPORT void prefs_base_folder_changed (GtkWidget *chooser, gpointer use
   g_free (current_uri);
 }
 
-void prefs_path_option_changed (GtkComboBox *combo, gpointer user_data)
+static void prefs_pattern_option_changed (GtkComboBox *combo, gpointer key)
 {
-  gint active;
   const char* pattern;
-  active = gtk_combo_box_get_active (combo);
-  if (active == -1)
-    return;
 
-  pattern = path_patterns[active].pattern;
+  pattern = gtk_combo_box_get_active_id (combo);
   if (pattern) {
-    g_settings_set_string (sj_settings, SJ_SETTINGS_PATH_PATTERN, pattern);
+    g_settings_set_string (sj_settings, key, pattern);
   }
 }
 
-G_MODULE_EXPORT void prefs_file_option_changed (GtkComboBox *combo, gpointer user_data)
-{
-  gint active;
-  const char* pattern;
-  active = gtk_combo_box_get_active (combo);
-  if (active == -1)
-    return;
-
-  pattern = file_patterns[active].pattern;
-  if (pattern) {
-    g_settings_set_string (sj_settings, SJ_SETTINGS_FILE_PATTERN, pattern);
-  }
-}
-
-static void
-sj_profile_option_set_active (GtkWidget *chooser, const char *profile)
-{
-  GtkTreeIter iter;
-  GtkTreeModel *model;
-  gboolean done;
-
-  done = FALSE;
-  model = gtk_combo_box_get_model(GTK_COMBO_BOX(chooser));
-  if (gtk_tree_model_get_iter_first (model, &iter)) {
-    do {
-      char *media_type;
-
-      gtk_tree_model_get (model, &iter, 0, &media_type, -1);
-      if (g_strcmp0 (media_type, profile) == 0) {
-        gtk_combo_box_set_active_iter (GTK_COMBO_BOX (chooser), &iter);
-        done = TRUE;
-      }
-      g_free (media_type);
-    } while (done == FALSE && gtk_tree_model_iter_next (model, &iter));
-  }
-
-  if (done == FALSE) {
-    gtk_combo_box_set_active_iter (GTK_COMBO_BOX (chooser), NULL);
-  }
-}
-
-static void audio_profile_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
-{
-  char *value;
-  g_return_if_fail (strcmp (key, SJ_SETTINGS_AUDIO_PROFILE) == 0);
-  value = g_settings_get_string (settings, key);
-  sj_profile_option_set_active (profile_option, value);
-  g_free (value);
-}
-
 static void baseuri_changed_cb  (GSettings *settings, gchar *key, gpointer user_data)
 {
   /*
@@ -321,35 +260,15 @@ static void pattern_label_update (void)
   g_free (format);
 }
 
-static void path_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
+static void settings_changed_cb (GSettings *settings, gchar *key, gpointer combo)
 {
   char *value;
-  int i = 0;
-  g_return_if_fail (strcmp (key, SJ_SETTINGS_PATH_PATTERN) == 0);
 
   value = g_settings_get_string (settings, key);
-  while (path_patterns[i].pattern && strcmp(path_patterns[i].pattern, value) != 0) {
-    i++;
-  }
+  if (!gtk_combo_box_set_active_id (combo, value))
+    gtk_combo_box_set_active_id (combo, NULL);
+
   g_free (value);
-  gtk_combo_box_set_active (GTK_COMBO_BOX (path_option), i);
-  pattern_label_update ();
-}
-
-static void file_pattern_changed_cb (GSettings *settings, gchar *key, gpointer user_data)
-{
-  char *value;
-  int i = 0;
-
-  g_return_if_fail (strcmp (key, SJ_SETTINGS_FILE_PATTERN) == 0);
-
-  value = g_settings_get_string (settings, key);
-
-  while (file_patterns[i].pattern && strcmp(file_patterns[i].pattern, value) != 0) {
-    i++;
-  }
-  g_free (value);
-  gtk_combo_box_set_active (GTK_COMBO_BOX (file_option), i);
   pattern_label_update ();
 }
 
@@ -417,6 +336,7 @@ static void populate_pattern_combo (GtkComboBox *combo, const FilePattern *patte
     gtk_list_store_set (store, &iter, 0, _(patterns[i].name), 1, patterns[i].pattern, -1);
   }
   gtk_combo_box_set_model (combo, GTK_TREE_MODEL (store));
+  g_object_unref (store);
 }
 
 static void
@@ -435,7 +355,7 @@ static void populate_profile_combo (GtkComboBox *combo)
   const GList *p;
   GtkTreeModel *model;
 
-  model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER));
+  model = GTK_TREE_MODEL (gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
 
   target = rb_gst_get_default_encoding_target ();
   for (p = gst_encoding_target_get_profiles (target); p != NULL; p = p->next) {
@@ -450,11 +370,12 @@ static void populate_profile_combo (GtkComboBox *combo)
                                        NULL, NULL, -1,
                                        0, media_type,
                                        1, gst_encoding_profile_get_description (profile),
-                                       2, profile, -1);
+                                       -1);
     g_free (media_type);
   }
 
   gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
+  g_object_unref (model);
 }
 
 /**
@@ -467,9 +388,8 @@ void show_preferences_dialog ()
   if (prefs_dialog) {
     gtk_window_present (GTK_WINDOW (prefs_dialog));
   } else {
-    const char *labels[] = { "cd_label", "path_label", "folder_label", "file_label", "profile_label" };
-    guint i;
-    GtkSizeGroup *group;
+    static gchar *path_key = SJ_SETTINGS_PATH_PATTERN;
+    static gchar *file_key = SJ_SETTINGS_FILE_PATTERN;
 
     prefs_dialog = GET_WIDGET ("prefs_dialog");
     g_assert (prefs_dialog != NULL);
@@ -477,18 +397,6 @@ void show_preferences_dialog ()
 
     gtk_window_set_transient_for (GTK_WINDOW (prefs_dialog), GTK_WINDOW (main_window));
 
-    group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-    for (i = 0; i < G_N_ELEMENTS (labels); i++) {
-      GtkWidget *widget;
-      widget = GET_WIDGET (labels[i]);
-      if (widget) {
-        gtk_size_group_add_widget (group, widget);
-      } else {
-        g_warning ("Widget %s not found", labels[i]);
-      }
-    }
-    g_object_unref (group);
-
     cd_option          = GET_WIDGET ("cd_option");
     basepath_fcb       = GET_WIDGET ("path_chooser");
     path_option        = GET_WIDGET ("path_option");
@@ -501,9 +409,9 @@ void show_preferences_dialog ()
 
     sj_add_default_dirs (GTK_FILE_CHOOSER (basepath_fcb));
     populate_pattern_combo (GTK_COMBO_BOX (path_option), path_patterns);
-    g_signal_connect (path_option, "changed", G_CALLBACK (prefs_path_option_changed), NULL);
+    g_signal_connect (path_option, "changed", G_CALLBACK (prefs_pattern_option_changed), path_key);
     populate_pattern_combo (GTK_COMBO_BOX (file_option), file_patterns);
-    g_signal_connect (file_option, "changed", G_CALLBACK (prefs_file_option_changed), NULL);
+    g_signal_connect (file_option, "changed", G_CALLBACK (prefs_pattern_option_changed), file_key);
     populate_profile_combo (GTK_COMBO_BOX (profile_option));
     g_signal_connect (profile_option, "changed", G_CALLBACK (prefs_profile_changed), NULL);
 
@@ -518,20 +426,20 @@ void show_preferences_dialog ()
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_BASEURI,
                       (GCallback)baseuri_changed_cb, NULL);
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_AUDIO_PROFILE,
-                      (GCallback)audio_profile_changed_cb, NULL);
+                      (GCallback)settings_changed_cb, profile_option);
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_PATH_PATTERN,
-                      (GCallback)path_pattern_changed_cb, NULL);
+                      (GCallback)settings_changed_cb, path_option);
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_FILE_PATTERN,
-                      (GCallback)file_pattern_changed_cb, NULL);
+                      (GCallback)settings_changed_cb, file_option);
     g_signal_connect (G_OBJECT (sj_settings), "changed::"SJ_SETTINGS_STRIP,
                       (GCallback)strip_changed_cb, NULL);
 
     g_signal_connect (extractor, "notify::profile", pattern_label_update, NULL);
 
     baseuri_changed_cb (sj_settings, SJ_SETTINGS_BASEURI, NULL);
-    audio_profile_changed_cb (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, NULL);
-    file_pattern_changed_cb (sj_settings, SJ_SETTINGS_FILE_PATTERN, NULL);
-    path_pattern_changed_cb (sj_settings, SJ_SETTINGS_PATH_PATTERN, NULL);
+    settings_changed_cb (sj_settings, SJ_SETTINGS_AUDIO_PROFILE, profile_option);
+    settings_changed_cb (sj_settings, SJ_SETTINGS_FILE_PATTERN, file_option);
+    settings_changed_cb (sj_settings, SJ_SETTINGS_PATH_PATTERN, path_option);
     device_changed_cb (sj_settings, SJ_SETTINGS_DEVICE, NULL);
 
     g_signal_connect (GTK_DIALOG (prefs_dialog), "response", G_CALLBACK (on_response), NULL);
